Class BasePathElementAccess
java.lang.Object
io.github.mmm.code.base.BasePathElementAccess
- Direct Known Subclasses:
BaseNodeItemContainerAccess
Class to extend by internal implementation classes to get internal access to
BasePathElements.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected static voidaddPathElementInternal(BasePathElements pathElements, BasePathElement item) protected static BasePackagegetPackage(BasePathElements start, io.github.mmm.code.api.CodeName path, boolean init, BiFunction<BasePackage, String, BasePackage> factory, boolean add, boolean forceAdd) Attention: This is an internal API that should not be used from outside.
-
Constructor Details
-
BasePathElementAccess
public BasePathElementAccess()
-
-
Method Details
-
addPathElementInternal
- Parameters:
pathElements- theBasePathElementswhere to add to.item- theBasePathElementto add.
-
getPackage
protected static BasePackage getPackage(BasePathElements start, io.github.mmm.code.api.CodeName path, boolean init, BiFunction<BasePackage, String, BasePackage> factory, boolean add, boolean forceAdd) Attention: This is an internal API that should not be used from outside.- Parameters:
start- theBasePathElementwhere to start.path- theCodeNameto traverse.init- -trueto initialize,falseotherwise.factory- theBiFunctionused as factory to create missing packages.add- -trueto add new packages created by the givenfactory,falseotherwise.forceAdd- -trueto force adding (ifaddistruebut is immutable),falseotherwise.- Returns:
- the traversed
BasePackage. Has been created if it did not already exist and was produced by the givenfactory. - See Also:
-