Class BaseExceptions
java.lang.Object
io.github.mmm.code.base.item.BaseItem
io.github.mmm.code.base.item.BaseMutableItem
io.github.mmm.code.base.node.BaseNodeItem
io.github.mmm.code.base.node.BaseNodeItemContainer<io.github.mmm.code.api.arg.CodeException>
io.github.mmm.code.base.node.BaseNodeItemContainerFlat<io.github.mmm.code.api.arg.CodeException>
io.github.mmm.code.base.arg.BaseOperationArgs<io.github.mmm.code.api.arg.CodeException>
io.github.mmm.code.base.arg.BaseExceptions
- All Implemented Interfaces:
io.github.mmm.code.api.arg.CodeExceptions, io.github.mmm.code.api.arg.CodeOperationArgs<io.github.mmm.code.api.arg.CodeException>, io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.member.CodeOperation, io.github.mmm.code.api.arg.CodeExceptions>, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaringType, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.merge.CodeMergeableItem<io.github.mmm.code.api.arg.CodeExceptions>, io.github.mmm.code.api.merge.CodeSimpleMergeableItem<io.github.mmm.code.api.arg.CodeExceptions>, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<io.github.mmm.code.api.arg.CodeException>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.arg.CodeException>, io.github.mmm.code.api.node.CodeNodeItemContainerFlat<io.github.mmm.code.api.arg.CodeException>, io.github.mmm.code.api.object.CodeMutable, Iterable<io.github.mmm.code.api.arg.CodeException>
public class BaseExceptions
extends BaseOperationArgs<io.github.mmm.code.api.arg.CodeException>
implements io.github.mmm.code.api.arg.CodeExceptions
Base implementation of
CodeExceptions.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface io.github.mmm.code.api.item.CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Constructor Summary
ConstructorsConstructorDescriptionBaseExceptions(BaseExceptions template, io.github.mmm.code.api.copy.CodeCopyMapper mapper) The copy-constructor.BaseExceptions(BaseOperation parent) The constructor. -
Method Summary
Modifier and TypeMethodDescriptionio.github.mmm.code.api.arg.CodeExceptionadd(io.github.mmm.code.api.type.CodeGenericType type) copy()copy(io.github.mmm.code.api.copy.CodeCopyMapper mapper) protected voidCalled fromBaseMutableItem.initialize()on first invocation.protected voiddoWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) io.github.mmm.code.api.arg.CodeExceptionget(io.github.mmm.code.api.type.CodeGenericType type) io.github.mmm.code.api.arg.CodeExceptionsio.github.mmm.code.api.arg.CodeExceptionsmerge(io.github.mmm.code.api.arg.CodeExceptions o, io.github.mmm.code.api.merge.CodeMergeStrategy strategy) Methods inherited from class BaseOperationArgs
getDeclaringType, getParentMethods inherited from class BaseNodeItemContainer
add, addInternal, clear, doSetImmutable, ensureParent, getByName, getDeclared, getItemCopyType, getKey, getList, getMap, isKeepListView, isNamed, isSystemImmutable, remove, renameMethods inherited from class BaseNodeItem
getContainerItem, getContainerItemDeclared, getContext, getLanguage, getSource, toPathStringMethods inherited from class BaseMutableItem
doCopyNode, doCopyNodeUnsafe, doMapList, doneInitialize, getDefaultCopyMapper, getDefaultEncoding, getReflectiveObject, initialize, initialize, isImmutable, isInitialized, isInitializing, isSystemImmutable, makeImmutable, makeImmutable, setImmutable, setImmutableIfNotSystemImmutable, verifyMutalbe, writeItemMethods inherited from class BaseItem
getOwningType, getSourceCode, getSpaces, toString, writeMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface io.github.mmm.code.api.arg.CodeExceptions
getOrCreateMethods inherited from interface io.github.mmm.code.api.item.CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface io.github.mmm.code.api.item.CodeItemWithDeclaringType
getDeclaringTypeMethods inherited from interface io.github.mmm.code.api.object.CodeMutable
isImmutable, isMutableMethods inherited from interface io.github.mmm.code.api.item.CodeMutableItem
getReflectiveObject, setImmutableMethods inherited from interface io.github.mmm.code.api.node.CodeNodeContainer
getDeclared, isEmpty, iteratorMethods inherited from interface io.github.mmm.code.api.node.CodeNodeItemContainer
removeMethods inherited from interface io.github.mmm.code.api.copy.CodeNodeItemCopyable
getParentMethods inherited from interface io.github.mmm.code.api.arg.CodeOperationArgs
getParentMethods inherited from interface io.github.mmm.code.api.merge.CodeSimpleMergeableItem
mergeMethods inherited from interface io.github.mmm.code.api.CodeWithContext
getContext, getSourceMethods inherited from interface Iterable
forEach, spliterator
-
Constructor Details
-
BaseExceptions
-
BaseExceptions
The copy-constructor.- Parameters:
template- theBaseExceptionsto copy.mapper- theCodeCopyMapper.
-
-
Method Details
-
doInitialize
protected void doInitialize()Description copied from class:BaseNodeItemCalled fromBaseMutableItem.initialize()on first invocation. May be overridden but never be called from anywhere else.- Overrides:
doInitializein classBaseNodeItem
-
get
public io.github.mmm.code.api.arg.CodeException get(io.github.mmm.code.api.type.CodeGenericType type) - Specified by:
getin interfaceio.github.mmm.code.api.arg.CodeExceptions
-
add
public io.github.mmm.code.api.arg.CodeException add(io.github.mmm.code.api.type.CodeGenericType type) - Specified by:
addin interfaceio.github.mmm.code.api.arg.CodeExceptions
-
getSourceCodeObject
public io.github.mmm.code.api.arg.CodeExceptions getSourceCodeObject()- Specified by:
getSourceCodeObjectin classBaseOperationArgs<io.github.mmm.code.api.arg.CodeException>- Returns:
- the optional internal
CodeItemrepresenting the source-code (to merge). Otherwisenull. This is an internal API. Do not use or rely on it from outside.
-
merge
public io.github.mmm.code.api.arg.CodeExceptions merge(io.github.mmm.code.api.arg.CodeExceptions o, io.github.mmm.code.api.merge.CodeMergeStrategy strategy) - Specified by:
mergein interfaceio.github.mmm.code.api.merge.CodeSimpleMergeableItem<io.github.mmm.code.api.arg.CodeExceptions>
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.arg.CodeExceptions- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.arg.CodeException>- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerFlat<io.github.mmm.code.api.arg.CodeException>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.member.CodeOperation, io.github.mmm.code.api.arg.CodeExceptions>- Specified by:
copyin interfaceio.github.mmm.code.api.arg.CodeOperationArgs<io.github.mmm.code.api.arg.CodeException>- Specified by:
copyin classBaseOperationArgs<io.github.mmm.code.api.arg.CodeException>
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.arg.CodeException>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.member.CodeOperation, io.github.mmm.code.api.arg.CodeExceptions>
-
doWrite
protected void doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) throws IOException - Specified by:
doWritein classBaseItem- Parameters:
sink- theAppendablewhere toappendthe code from thisCodeItem.newline- the newlineString.defaultIndent- theStringused for indentation (e.g. a number of spaces to insert per indent level).currentIndent- the current indent (number of spaces). Initially the empty string (""). Before a recursion thedefaultIndentwill be appended.language- theCodeLanguageto use.- Throws:
IOException- if thrown byAppendable.- See Also:
-