Class BaseDocParser

java.lang.Object
io.github.mmm.code.base.doc.BaseDocParser

public class BaseDocParser extends Object
Parser to parse and apply CodeDoc read as plain lines of Strings from the source code to CodeElements.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseDocParser

      public BaseDocParser()
      The constructor.
  • Method Details

    • parseDoc

      public void parseDoc(io.github.mmm.code.api.member.CodeOperation operation, List<String> javaDocLines)
      Parameters:
      operation - the CodeOperation that has already been created with its entire signature.
      javaDocLines - the List of plain CodeDoc lines to parse and apply to the given CodeOperation.
    • parseDoc

      public void parseDoc(io.github.mmm.code.api.type.CodeType type, List<String> javaDocLines)
      Parameters:
      type - the CodeType that has already been created with type variables.
      javaDocLines - the List of plain CodeDoc lines to parse and apply to the given CodeType.
    • parseDoc

      public void parseDoc(io.github.mmm.code.api.member.CodeField field, List<String> javaDocLines)
      Parameters:
      field - the CodeField.
      javaDocLines - the List of plain CodeDoc lines to parse and apply to the given CodeField.