Class BaseArrayInstatiation

All Implemented Interfaces:
io.github.mmm.code.api.expression.CodeArrayInstatiation, io.github.mmm.code.api.expression.CodeExpression, io.github.mmm.code.api.item.CodeItem

public class BaseArrayInstatiation extends BaseExpression implements io.github.mmm.code.api.expression.CodeArrayInstatiation
Base implementation of CodeArrayInstatiatioHashMap-
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseArrayInstatiation

      public BaseArrayInstatiation(List<io.github.mmm.code.api.expression.CodeExpression> values)
      The constructor.
      Parameters:
      values - the values.
  • Method Details

    • evaluate

      public io.github.mmm.code.api.expression.CodeConstant evaluate()
      Specified by:
      evaluate in interface io.github.mmm.code.api.expression.CodeExpression
    • getValues

      public List<io.github.mmm.code.api.expression.CodeExpression> getValues()
      Specified by:
      getValues in interface io.github.mmm.code.api.expression.CodeArrayInstatiation
    • doWrite

      protected void doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) throws IOException
      Specified by:
      doWrite in class BaseItem
      Parameters:
      sink - the Appendable where to append the code from this CodeItem.
      newline - the newline String.
      defaultIndent - the String used for indentation (e.g. a number of spaces to insert per indent level).
      currentIndent - the current indent (number of spaces). Initially the empty string (""). Before a recursion the defaultIndent will be appended.
      language - the CodeLanguage to use.
      Throws:
      IOException - if thrown by Appendable.
      See Also:
      • CodeItem.write(Appendable, String, String)