Class BaseVariableThis

All Implemented Interfaces:
io.github.mmm.code.api.expression.CodeExpression, io.github.mmm.code.api.expression.CodeVariable, io.github.mmm.code.api.expression.CodeVariableThis, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaration, io.github.mmm.code.api.item.CodeItemWithName, io.github.mmm.code.api.item.CodeItemWithType

public class BaseVariableThis extends BaseExpression implements io.github.mmm.code.api.expression.CodeVariableThis
Generic implementation of CodeVariableThis using CodeVariableThis.NAME_THIS.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Field Summary

    Fields inherited from interface io.github.mmm.code.api.item.CodeItem

    DEFAULT_INDENT, DEFAULT_NEWLINE

    Fields inherited from interface io.github.mmm.code.api.expression.CodeVariableThis

    NAME_SELF, NAME_THIS
  • Constructor Summary

    Constructors
    Constructor
    Description
    BaseVariableThis(io.github.mmm.code.api.type.CodeGenericType type)
    The constructor.
  • Method Summary

    Modifier and Type
    Method
    Description
    protected void
    doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language)
     
    io.github.mmm.code.api.expression.CodeConstant
     
     
    io.github.mmm.code.api.type.CodeGenericType
     

    Methods inherited from class BaseItem

    getOwningType, getSourceCode, getSpaces, toString, write

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait

    Methods inherited from interface io.github.mmm.code.api.item.CodeItem

    getLanguage, getSourceCode, write, write, write, write, write, write

    Methods inherited from interface io.github.mmm.code.api.item.CodeItemWithDeclaration

    writeReference

    Methods inherited from interface io.github.mmm.code.api.expression.CodeVariable

    writeReference
  • Constructor Details

    • BaseVariableThis

      public BaseVariableThis(io.github.mmm.code.api.type.CodeGenericType type)
      The constructor.
      Parameters:
      type - the type.
  • Method Details

    • evaluate

      public io.github.mmm.code.api.expression.CodeConstant evaluate()
      Specified by:
      evaluate in interface io.github.mmm.code.api.expression.CodeExpression
    • getType

      public io.github.mmm.code.api.type.CodeGenericType getType()
      Specified by:
      getType in interface io.github.mmm.code.api.item.CodeItemWithType
    • getName

      public String getName()
      Specified by:
      getName in interface io.github.mmm.code.api.item.CodeItemWithName
    • doWrite

      protected void doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) throws IOException
      Specified by:
      doWrite in class BaseItem
      Parameters:
      sink - the Appendable where to append the code from this CodeItem.
      newline - the newline String.
      defaultIndent - the String used for indentation (e.g. a number of spaces to insert per indent level).
      currentIndent - the current indent (number of spaces). Initially the empty string (""). Before a recursion the defaultIndent will be appended.
      language - the CodeLanguage to use.
      Throws:
      IOException - if thrown by Appendable.
      See Also:
      • CodeItem.write(Appendable, String, String)