Interface SourceCodeProvider

All Superinterfaces:
AutoCloseable
All Known Implementing Classes:
BaseSourceCodeProvider, BaseSourceCodeProviderArchive, BaseSourceCodeProviderDirectory, SourceCodeProviderNone, SourceCodeProviderProxy

public interface SourceCodeProvider extends AutoCloseable
The interface for a provider of source-code from an arbitrary location.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • openType

      Reader openType(String qualifiedName) throws IOException
      Parameters:
      qualifiedName - the qualified name of the CodeType to open.
      Returns:
      a new Reader to read the source-code from or null if the requested type was not found.
      Throws:
      IOException - on I/O error.
      See Also:
    • openPackage

      Reader openPackage(String qualifiedName) throws IOException
      Parameters:
      qualifiedName - the qualified name of the CodePackage to open.
      Returns:
      a new Reader to read the source-code from or null if the requested package was not found.
      Throws:
      IOException - on I/O error.
    • scanPackage

      List<String> scanPackage(String qualifiedName) throws IOException
      Parameters:
      qualifiedName - the qualified name of the CodePackage to scan.
      Returns:
      a List with the simple names of the CodeTypes in the specified package or null if scan is not supported.
      Throws:
      IOException - on I/O error.
    • close

      void close()
      Specified by:
      close in interface AutoCloseable