Class SourceCodeProviderNone
java.lang.Object
io.github.mmm.code.base.loader.SourceCodeProviderNone
- All Implemented Interfaces:
SourceCodeProvider, AutoCloseable
Empty implementation of
SourceCodeProvider for no sources.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields -
Method Summary
-
Field Details
-
INSTANCE
The singleton instance.
-
-
Method Details
-
openType
- Specified by:
openTypein interfaceSourceCodeProvider- Parameters:
qualifiedName- the qualified name of theCodeTypeto open.- Returns:
- a new
Readerto read the source-code from ornullif the requested type was not found. - Throws:
IOException- on I/O error.- See Also:
-
openPackage
- Specified by:
openPackagein interfaceSourceCodeProvider- Parameters:
qualifiedName- the qualified name of theCodePackageto open.- Returns:
- a new
Readerto read the source-code from ornullif the requested package was not found. - Throws:
IOException- on I/O error.
-
scanPackage
- Specified by:
scanPackagein interfaceSourceCodeProvider- Parameters:
qualifiedName- the qualified name of theCodePackageto scan.- Returns:
- a
Listwith thesimple namesof theCodeTypes in the specified package ornullif scan is not supported. - Throws:
IOException- on I/O error.
-
close
public void close()- Specified by:
closein interfaceAutoCloseable- Specified by:
closein interfaceSourceCodeProvider
-