Class BaseMethods

All Implemented Interfaces:
io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaringType, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.member.CodeMethods, io.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.merge.CodeAdvancedMergeableItem<io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.merge.CodeMergeableItem<io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.object.CodeMutable, Iterable<io.github.mmm.code.api.member.CodeMethod>

public class BaseMethods extends BaseOperations<io.github.mmm.code.api.member.CodeMethod> implements io.github.mmm.code.api.member.CodeMethods
Base implementation of CodeMethods.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseMethods

      public BaseMethods(BaseType declaringType)
      The constructor.
      Parameters:
      declaringType - the BaseMembers.getDeclaringType().
    • BaseMethods

      public BaseMethods(BaseMethods template, io.github.mmm.code.api.copy.CodeCopyMapper mapper)
      The copy-constructor.
      Parameters:
      template - the BaseMethods to copy.
      mapper - the CodeCopyMapper.
  • Method Details

    • doInitialize

      protected void doInitialize()
      Description copied from class: BaseNodeItem
      Called from BaseMutableItem.initialize() on first invocation. May be overridden but never be called from anywhere else.
      Overrides:
      doInitialize in class BaseNodeItem
    • getAll

      public Iterable<? extends io.github.mmm.code.api.member.CodeMethod> getAll()
      Specified by:
      getAll in interface io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>
    • get

      public io.github.mmm.code.api.member.CodeMethod get(io.github.mmm.code.api.member.CodeMethod method)
      Specified by:
      get in interface io.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>
    • getDeclared

      public io.github.mmm.code.api.member.CodeMethod getDeclared(String name, io.github.mmm.code.api.type.CodeGenericType... parameterTypes)
      Specified by:
      getDeclared in interface io.github.mmm.code.api.member.CodeMethods
    • add

      public BaseMethod add(String name)
      Specified by:
      add in interface io.github.mmm.code.api.member.CodeMethods
    • getSourceCodeObject

      public io.github.mmm.code.api.member.CodeMethods getSourceCodeObject()
      Specified by:
      getSourceCodeObject in class BaseOperations<io.github.mmm.code.api.member.CodeMethod>
      Returns:
      the optional internal CodeItem representing the source-code (to merge). Otherwise null. This is an internal API. Do not use or rely on it from outside.
    • merge

      public io.github.mmm.code.api.member.CodeMethods merge(io.github.mmm.code.api.member.CodeMethods other, io.github.mmm.code.api.merge.CodeMergeStrategyDecider decider, io.github.mmm.code.api.merge.CodeMergeStrategy parentStrategy)
      Specified by:
      merge in interface io.github.mmm.code.api.merge.CodeAdvancedMergeableItem<io.github.mmm.code.api.member.CodeMethods>
    • copy

      public BaseMethods copy()
      Specified by:
      copy in interface io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeMethod>
      Specified by:
      copy in interface io.github.mmm.code.api.member.CodeMethods
      Specified by:
      copy in interface io.github.mmm.code.api.item.CodeMutableItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>
      Specified by:
      copy in interface io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>
      Specified by:
      copy in interface io.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>
      Specified by:
      copy in class BaseOperations<io.github.mmm.code.api.member.CodeMethod>
    • copy

      public BaseMethods copy(io.github.mmm.code.api.copy.CodeCopyMapper mapper)
      Specified by:
      copy in interface io.github.mmm.code.api.item.CodeMutableItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>
      Specified by:
      copy in interface io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>