Class BaseProperties

All Implemented Interfaces:
io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaringType, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.member.CodeProperties, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.object.CodeMutable, Iterable<io.github.mmm.code.api.member.CodeProperty>

public class BaseProperties extends BaseMembers<io.github.mmm.code.api.member.CodeProperty> implements io.github.mmm.code.api.member.CodeProperties
Base implementation of CodeProperties.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseProperties

      public BaseProperties(BaseType parent)
      The constructor.
      Parameters:
      parent - the parent.
    • BaseProperties

      public BaseProperties(BaseProperties template, io.github.mmm.code.api.copy.CodeCopyMapper mapper)
      The copy-constructor.
      Parameters:
      template - the BaseProperties to copy.
      mapper - the CodeCopyMapper.
  • Method Details

    • doInitialize

      protected void doInitialize()
      Description copied from class: BaseNodeItem
      Called from BaseMutableItem.initialize() on first invocation. May be overridden but never be called from anywhere else.
      Overrides:
      doInitialize in class BaseNodeItem
    • getAll

      public Iterable<? extends io.github.mmm.code.api.member.CodeProperty> getAll()
      Specified by:
      getAll in interface io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>
    • get

      public io.github.mmm.code.api.member.CodeProperty get(String name)
      Specified by:
      get in interface io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
    • add

      public BaseProperty add(String name)
      Specified by:
      add in interface io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      add in interface io.github.mmm.code.api.member.CodeProperties
    • getDeclared

      public io.github.mmm.code.api.member.CodeProperty getDeclared(String name)
      Specified by:
      getDeclared in interface io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
    • getSourceCodeObject

      @Deprecated public io.github.mmm.code.api.member.CodeProperties getSourceCodeObject()
      Deprecated.
      a BaseProperties is a virtual object that can never have a source-code object.
      Specified by:
      getSourceCodeObject in class BaseMembers<io.github.mmm.code.api.member.CodeProperty>
      Returns:
      the optional internal CodeItem representing the source-code (to merge). Otherwise null. This is an internal API. Do not use or rely on it from outside.
    • copy

      public BaseProperties copy()
      Specified by:
      copy in interface io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.item.CodeMutableItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>
      Specified by:
      copy in interface io.github.mmm.code.api.member.CodeProperties
      Specified by:
      copy in class BaseMembers<io.github.mmm.code.api.member.CodeProperty>
    • copy

      public BaseProperties copy(io.github.mmm.code.api.copy.CodeCopyMapper mapper)
      Specified by:
      copy in interface io.github.mmm.code.api.item.CodeMutableItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItem
      Specified by:
      copy in interface io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>
      Specified by:
      copy in interface io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>