Class BaseNodeItemContainerHierarchicalWithName<I extends io.github.mmm.code.api.item.CodeItem>

Type Parameters:
I - the type of the contained CodeItem.
All Implemented Interfaces:
io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<I>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<I>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<I>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<I>, io.github.mmm.code.api.node.CodeNodeItemContainerWithName<I>, io.github.mmm.code.api.object.CodeMutable, Iterable<I>
Direct Known Subclasses:
BaseNestedTypes

public abstract class BaseNodeItemContainerHierarchicalWithName<I extends io.github.mmm.code.api.item.CodeItem> extends BaseNodeItemContainerWithName<I> implements io.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<I>
Base implementation of CodeNodeItemContainerHierarchicalWithName.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseNodeItemContainerHierarchicalWithName

      protected BaseNodeItemContainerHierarchicalWithName()
      The constructor.
    • BaseNodeItemContainerHierarchicalWithName

      public BaseNodeItemContainerHierarchicalWithName(BaseNodeItemContainerHierarchicalWithName<I> template, io.github.mmm.code.api.copy.CodeCopyMapper mapper)
      The copy-constructor.
      Parameters:
      template - the BaseNodeItemContainerHierarchicalWithName to copy.
      mapper - the CodeCopyMapper.
  • Method Details

    • get

      protected abstract I get(String name, boolean init)
      Overrides:
      get in class BaseNodeItemContainerWithName<I extends io.github.mmm.code.api.item.CodeItem>
      Parameters:
      name - the name of the requested CodeItem.
      init - true to ensure this container is initialized, false otherwise.
      Returns:
      the CodeItem from declared items with the given name or null if no such item exists.