Uses of Interface
io.github.mmm.code.base.source.BaseSource
Packages that use BaseSource
Package
Description
-
Uses of BaseSource in io.github.mmm.code.base
Methods in io.github.mmm.code.base that return BaseSourceModifier and TypeMethodDescriptionAbstractBaseContextWithCache.getOrCreateSource(File byteCodeLocation, File sourceCodeLocation) This is an internal method that should only be used from implementations ofBaseSourceProvider.AbstractBaseContextWithCache.getOrCreateSource(String id, Supplier<BaseSource> sourceSupplier) Attention: This is an internal method that shall not be used from outside.protected BaseSourceAbstractBaseContextWithCache.getOrCreateSource(CodeSource codeSource) AbstractBaseContext.getSource()BasePackage.getSource()BaseProvider.getSource()Method parameters in io.github.mmm.code.base with type arguments of type BaseSourceModifier and TypeMethodDescriptionAbstractBaseContextWithCache.getOrCreateSource(String id, Supplier<BaseSource> sourceSupplier) Attention: This is an internal method that shall not be used from outside.Constructors in io.github.mmm.code.base with parameters of type BaseSource -
Uses of BaseSource in io.github.mmm.code.base.loader
Methods in io.github.mmm.code.base.loader that return BaseSource -
Uses of BaseSource in io.github.mmm.code.base.node
Methods in io.github.mmm.code.base.node that return BaseSource -
Uses of BaseSource in io.github.mmm.code.base.source
Classes in io.github.mmm.code.base.source that implement BaseSourceClasses in io.github.mmm.code.base.source that implement interfaces with type arguments of type BaseSourceModifier and TypeClassDescriptionclassImplementation ofCodeSourceDependenciesfor Java.Methods in io.github.mmm.code.base.source that return BaseSourceModifier and TypeMethodDescriptionBaseSourceProvider.create(CodeSource source) BaseSource.getParent()BaseSourceDependencies.getParent()BaseSourceImpl.getParent()default BaseSourceBaseSource.getSource()BaseSourceDependencies.getSource()Methods in io.github.mmm.code.base.source that return types with arguments of type BaseSourceModifier and TypeMethodDescriptionList<? extends BaseSource> BaseSourceDependencies.getDeclared()Constructors in io.github.mmm.code.base.source with parameters of type BaseSourceModifierConstructorDescriptionBaseSourceDependencies(BaseSource parent, Supplier<List<BaseSource>> lazyInit) The constructor.BaseSourceDependencies(BaseSource parent, List<BaseSource> dependencies) The constructor.Constructor parameters in io.github.mmm.code.base.source with type arguments of type BaseSourceModifierConstructorDescriptionBaseSourceDependencies(BaseSource parent, Supplier<List<BaseSource>> lazyInit) The constructor.BaseSourceDependencies(BaseSource parent, List<BaseSource> dependencies) The constructor.BaseSourceImpl(CodeSource reflectiveObject, File byteCodeLocation, File sourceCodeLocation, String id, io.github.mmm.code.api.source.CodeSourceDescriptor descriptor, List<BaseSource> dependencies, BaseSourceLoader loader, boolean immutable) The constructor. -
Uses of BaseSource in io.github.mmm.code.base.statement
Constructors in io.github.mmm.code.base.statement with parameters of type BaseSourceModifierConstructorDescriptionBaseLocalVariable(BaseSource source, String name, io.github.mmm.code.api.type.CodeGenericType type, io.github.mmm.code.api.expression.CodeExpression expression, boolean finalFlag) The constructor.