Class BaseTextStatement

All Implemented Interfaces:
io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithVariables, io.github.mmm.code.api.statement.CodeAtomicStatement, io.github.mmm.code.api.statement.CodeStatement

public class BaseTextStatement extends BaseAtomicStatement
Base implementation of CodeStatement that is unstructured and only contains the source-code as a plain text.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Constructor Details

    • BaseTextStatement

      public BaseTextStatement(String code)
      The constructor.
      Parameters:
      code - the code.
  • Method Details

    • getCode

      public String getCode()
      Returns:
      the line
    • doWrite

      protected void doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) throws IOException
      Specified by:
      doWrite in class BaseItem
      Parameters:
      sink - the Appendable where to append the code from this CodeItem.
      newline - the newline String.
      defaultIndent - the String used for indentation (e.g. a number of spaces to insert per indent level).
      currentIndent - the current indent (number of spaces). Initially the empty string (""). Before a recursion the defaultIndent will be appended.
      language - the CodeLanguage to use.
      Throws:
      IOException - if thrown by Appendable.
      See Also:
      • CodeItem.write(Appendable, String, String)