All Classes and Interfaces
Class
Description
Base implementation of
BaseContext.Extends
AbstractBaseContext with caching to speed up lookups.Base implementation of
BaseProvider.Base implementation of
CodeAnnotation.Base implementation of
CodeAnnotations.Base implementation of CodeArrayInstatiatio
HashMap-Base implementation of
BaseGenericType for array.Base implementation of
CodeAtomicStatement.Base implementation of
CodeBlock.Base implementation of
CodeBlockBody.Base implementation of
CodeBlockComment.Base implementation of
CodeBlockDoWhile.Base implementation of
CodeBlockFor.Base implementation of
CodeBlockDoWhile.Base implementation of
CodeBlockBody.Base implementation of
CodeBlockStatement.Base implementation of
CodeBlockStatement.Base implementation of
CodeBlockStatement.Base implementation of
CodeBlockDoWhile.Generic implementation of
CodeCastExpression.Base implementation of
CodeComment.Base implementation of
CodeComments.Base implementation of
CodeComparisonOperator.Generic implementation of
CodeComparisonOperatorExpression.Base implementation of
CodeComposedType.Base or dummy implementation of
CodeConstant.Base implementation of
CodeConstructor.Base implementation of
CodeMethods.Base interface for
CodeContext.Implementation of
AbstractBaseContext for child context.Base implementation of
CodeDoc.Base implementation of
CodeDocLink.Base implementation of
CodeDocMethodLink.Parser to parse and apply
CodeDoc read as plain lines of Strings from the source code to
CodeElements.Base implementation of
CodeElement.Base implementation of
CodeElementWithDeclaringType.Implementation of
CodeElementWithModifiers for Java.Base implementation of
CodeMutableItemWithQualifiedName as BaseElement.Base implementation of
CodeException.Base implementation of
CodeExceptions.Generic implementation of
CodeExpression.Base implementation of
CodeFactory.Base implementation of
CodeField.Base implementation of
CodeFieldReference.Implementation of
CodeFieldReference with lazy evaluation.Base implementation of
CodeFields.Base implementation of
CodeFile.Base implementation of
CodeGenericType.Base implementation of
CodeGenericTypeParameters.Base implementation of
BaseGenericType for a proxy-type to a delegate.Base implementation of
CodeImport.Base implementation of
CodeImportItem (actually specific for TypeScript).Base implementation of
CodeImports.Base implementation of
CodeInlineComment.Base implementation of
CodeItem.CodeLoader for Java.Base implementation of
CodeLocalVariable.Base implementation of
CodeMember.Generic implementation of
CodeMemberReference.Base implementation of
CodeMembers.Base implementation of
CodeMethod.Base implementation of
CodeMethodInvocation.Base implementation of
CodeMethods.Base implementation of
CodeMutableItem.Base implementation of
CodeNAryArbitraryOperator.Base implementation of
CodeNAryBooleanOperator.Base implementation of
CodeNAryHybridOperator.Base implementation of
CodeNAryNumericOperator.Base implementation of
CodeNAryOperator.Generic implementation of
CodeNAryOperatorExpression.Base implementation of
CodeNestedTypes.Base implementation of
CodeNodeItem.Base implementation of
CodeNodeItemContainer.Class to extend by internal implementation classes to get internal access to
BaseNodeItemContainer.Base implementation of
CodeNodeItemContainerFlat.Base implementation of
CodeNodeItemContainerFlatWithName.Base implementation of
CodeNodeItemContainerHierarchical.Base implementation of
CodeNodeItemContainerHierarchicalWithName.Base implementation of
CodeNodeItemContainerWithName.Base implementation of
CodeOperation.Base implementation of
CodeOperationArg.Base implementation of
CodeOperationArgs.Implementation of
CodeMembers for Java.Base implementation of
CodeOperator.Generic implementation of
CodeOperatorExpression.Base implementation of
CodePackage.Base implementation of
CodeParameter.Base implementation of
CodeParameterizedType.Base implementation of
CodeParameters.Base implementation of
CodePathElement.Class to extend by internal implementation classes to get internal access to
BasePathElements.Base implementation of
CodePathElements.Base implementation of
CodeProperties.Base implementation of
CodeProperty.Base interface for
CodeProvider.Base implementation of
CodeReturn.Base implementation of
CodeSingleComment.Base implementation of
CodeSingleLineComment.Base implementation of
CodeSource.Abstract base implementation of
SourceCodeProvider.Base implementation of
BaseSourceCodeProvider for a source-code directory in the filesystem.Base implementation of
BaseSourceCodeProvider for a source-code directory in the filesystem.Implementation of
CodeSourceDependencies for Java.Base implementation of
CodeSourceDescriptor.Base implementation of
BaseSourceDescriptor as mutable Java bean.Base implementation of
BaseSourceDescriptor as immutable type.Simple helper class for implementations related to
BaseSource.Implementation of
CodeSource for Java.BaseLoader that encapsulates the physical loading of code from a
BaseSource.Abstract base implementation of
BaseSourceLoader.BaseSourceLoaderImpl to load from existing package structure in memory.Factory for
BaseSource to decouple from specific implementations such as maven or eclipse
environments.Abstract base implemenation of
BaseSourceProvider.Base implementation of
CodeStatement.Base implementation of
CodeSuperTypes.Generic implementation of
CodeTernaryExpression.Base implementation of
CodeStatement that is unstructured and only contains the source-code as a
plain text.Base implementation of
CodeType.Base implementation of
CodeTypeParameters.Base implementation of
CodeTypeVariable.Base implementation of
CodeTypeVariable.Base implementation of
CodeTypeVariables.Base implementation of
CodeTypeWildcard.Base implementation of
CodeUnaryOperator.Generic implementation of
CodeUnaryOperatorExpression.Generic implementation of
CodeVariableThis using CodeVariableThis.NAME_THIS.Internal class to iterate over all
super types of a
CodeType left recursively.Interface for a parser of Java source code.
The interface for a provider of source-code from an arbitrary location.
Empty implementation of
SourceCodeProvider for no sources.Implementation of
SourceCodeProvider for lazy instantiation.