Interface SourceCodeProvider
- All Superinterfaces:
AutoCloseable
- All Known Implementing Classes:
BaseSourceCodeProvider, BaseSourceCodeProviderArchive, BaseSourceCodeProviderDirectory, SourceCodeProviderNone, SourceCodeProviderProxy
The interface for a provider of source-code from an arbitrary location.
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Method Summary
-
Method Details
-
openType
- Parameters:
qualifiedName- the qualified name of theCodeTypeto open.- Returns:
- a new
Readerto read the source-code from ornullif the requested type was not found. - Throws:
IOException- on I/O error.- See Also:
-
openPackage
- Parameters:
qualifiedName- the qualified name of theCodePackageto open.- Returns:
- a new
Readerto read the source-code from ornullif the requested package was not found. - Throws:
IOException- on I/O error.
-
scanPackage
- Parameters:
qualifiedName- the qualified name of theCodePackageto scan.- Returns:
- a
Listwith thesimple namesof theCodeTypes in the specified package ornullif scan is not supported. - Throws:
IOException- on I/O error.
-
close
void close()- Specified by:
closein interfaceAutoCloseable
-