Class BaseMethods
java.lang.Object
io.github.mmm.code.base.item.BaseItem
io.github.mmm.code.base.item.BaseMutableItem
io.github.mmm.code.base.node.BaseNodeItem
io.github.mmm.code.base.node.BaseNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>
io.github.mmm.code.base.member.BaseMembers<io.github.mmm.code.api.member.CodeMethod>
io.github.mmm.code.base.member.BaseOperations<io.github.mmm.code.api.member.CodeMethod>
io.github.mmm.code.base.member.BaseMethods
- All Implemented Interfaces:
io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaringType, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.member.CodeMethods, io.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.merge.CodeAdvancedMergeableItem<io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.merge.CodeMergeableItem<io.github.mmm.code.api.member.CodeMethods>, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>, io.github.mmm.code.api.object.CodeMutable, Iterable<io.github.mmm.code.api.member.CodeMethod>
public class BaseMethods
extends BaseOperations<io.github.mmm.code.api.member.CodeMethod>
implements io.github.mmm.code.api.member.CodeMethods
Base implementation of
CodeMethods.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface io.github.mmm.code.api.item.CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Constructor Summary
ConstructorsConstructorDescriptionBaseMethods(BaseMethods template, io.github.mmm.code.api.copy.CodeCopyMapper mapper) The copy-constructor.BaseMethods(BaseType declaringType) The constructor. -
Method Summary
Modifier and TypeMethodDescriptioncopy()copy(io.github.mmm.code.api.copy.CodeCopyMapper mapper) protected voidCalled fromBaseMutableItem.initialize()on first invocation.io.github.mmm.code.api.member.CodeMethodget(io.github.mmm.code.api.member.CodeMethod method) Iterable<? extends io.github.mmm.code.api.member.CodeMethod> getAll()io.github.mmm.code.api.member.CodeMethodgetDeclared(String name, io.github.mmm.code.api.type.CodeGenericType... parameterTypes) io.github.mmm.code.api.member.CodeMethodsio.github.mmm.code.api.member.CodeMethodsmerge(io.github.mmm.code.api.member.CodeMethods other, io.github.mmm.code.api.merge.CodeMergeStrategyDecider decider, io.github.mmm.code.api.merge.CodeMergeStrategy parentStrategy) Methods inherited from class BaseMembers
add, doWrite, getDeclaringType, getParent, renameMethods inherited from class BaseNodeItemContainer
addInternal, clear, doSetImmutable, ensureParent, getByName, getDeclared, getItemCopyType, getKey, getList, getMap, isKeepListView, isNamed, isSystemImmutable, removeMethods inherited from class BaseNodeItem
getContainerItem, getContainerItemDeclared, getContext, getLanguage, getSource, toPathStringMethods inherited from class BaseMutableItem
doCopyNode, doCopyNodeUnsafe, doMapList, doneInitialize, getDefaultCopyMapper, getDefaultEncoding, getReflectiveObject, initialize, initialize, isImmutable, isInitialized, isInitializing, isSystemImmutable, makeImmutable, makeImmutable, setImmutable, setImmutableIfNotSystemImmutable, verifyMutalbe, writeItemMethods inherited from class BaseItem
getOwningType, getSourceCode, getSpaces, toString, writeMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface io.github.mmm.code.api.merge.CodeAdvancedMergeableItem
merge, mergeMethods inherited from interface io.github.mmm.code.api.item.CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface io.github.mmm.code.api.item.CodeItemWithDeclaringType
getDeclaringTypeMethods inherited from interface io.github.mmm.code.api.member.CodeMembers
add, getParentMethods inherited from interface io.github.mmm.code.api.member.CodeMethods
getFirst, getFirstOrCreateMethods inherited from interface io.github.mmm.code.api.object.CodeMutable
isImmutable, isMutableMethods inherited from interface io.github.mmm.code.api.item.CodeMutableItem
getReflectiveObject, setImmutableMethods inherited from interface io.github.mmm.code.api.node.CodeNodeContainer
getDeclared, isEmpty, iteratorMethods inherited from interface io.github.mmm.code.api.node.CodeNodeItemContainer
removeMethods inherited from interface io.github.mmm.code.api.copy.CodeNodeItemCopyable
getParentMethods inherited from interface io.github.mmm.code.api.CodeWithContext
getContext, getSourceMethods inherited from interface Iterable
forEach, spliterator
-
Constructor Details
-
BaseMethods
The constructor.- Parameters:
declaringType- theBaseMembers.getDeclaringType().
-
BaseMethods
The copy-constructor.- Parameters:
template- theBaseMethodsto copy.mapper- theCodeCopyMapper.
-
-
Method Details
-
doInitialize
protected void doInitialize()Description copied from class:BaseNodeItemCalled fromBaseMutableItem.initialize()on first invocation. May be overridden but never be called from anywhere else.- Overrides:
doInitializein classBaseNodeItem
-
getAll
- Specified by:
getAllin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>
-
get
public io.github.mmm.code.api.member.CodeMethod get(io.github.mmm.code.api.member.CodeMethod method) - Specified by:
getin interfaceio.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>
-
getDeclared
public io.github.mmm.code.api.member.CodeMethod getDeclared(String name, io.github.mmm.code.api.type.CodeGenericType... parameterTypes) - Specified by:
getDeclaredin interfaceio.github.mmm.code.api.member.CodeMethods
-
add
- Specified by:
addin interfaceio.github.mmm.code.api.member.CodeMethods
-
getSourceCodeObject
public io.github.mmm.code.api.member.CodeMethods getSourceCodeObject()- Specified by:
getSourceCodeObjectin classBaseOperations<io.github.mmm.code.api.member.CodeMethod>- Returns:
- the optional internal
CodeItemrepresenting the source-code (to merge). Otherwisenull. This is an internal API. Do not use or rely on it from outside.
-
merge
public io.github.mmm.code.api.member.CodeMethods merge(io.github.mmm.code.api.member.CodeMethods other, io.github.mmm.code.api.merge.CodeMergeStrategyDecider decider, io.github.mmm.code.api.merge.CodeMergeStrategy parentStrategy) - Specified by:
mergein interfaceio.github.mmm.code.api.merge.CodeAdvancedMergeableItem<io.github.mmm.code.api.member.CodeMethods>
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeMethod>- Specified by:
copyin interfaceio.github.mmm.code.api.member.CodeMethods- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeMethod>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>- Specified by:
copyin interfaceio.github.mmm.code.api.member.CodeOperations<io.github.mmm.code.api.member.CodeMethod>- Specified by:
copyin classBaseOperations<io.github.mmm.code.api.member.CodeMethod>
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeMethod>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeMethods>
-