Class BaseProperties
java.lang.Object
io.github.mmm.code.base.item.BaseItem
io.github.mmm.code.base.item.BaseMutableItem
io.github.mmm.code.base.node.BaseNodeItem
io.github.mmm.code.base.node.BaseNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>
io.github.mmm.code.base.member.BaseMembers<io.github.mmm.code.api.member.CodeProperty>
io.github.mmm.code.base.member.BaseProperties
- All Implemented Interfaces:
io.github.mmm.code.api.CodeWithContext, io.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>, io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithDeclaringType, io.github.mmm.code.api.item.CodeMutableItem, io.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.member.CodeProperties, io.github.mmm.code.api.node.CodeNode, io.github.mmm.code.api.node.CodeNodeContainer<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItem, io.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>, io.github.mmm.code.api.object.CodeMutable, Iterable<io.github.mmm.code.api.member.CodeProperty>
public class BaseProperties
extends BaseMembers<io.github.mmm.code.api.member.CodeProperty>
implements io.github.mmm.code.api.member.CodeProperties
Base implementation of
CodeProperties.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface io.github.mmm.code.api.item.CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Constructor Summary
ConstructorsConstructorDescriptionBaseProperties(BaseProperties template, io.github.mmm.code.api.copy.CodeCopyMapper mapper) The copy-constructor.BaseProperties(BaseType parent) The constructor. -
Method Summary
Modifier and TypeMethodDescriptioncopy()copy(io.github.mmm.code.api.copy.CodeCopyMapper mapper) protected voidCalled fromBaseMutableItem.initialize()on first invocation.io.github.mmm.code.api.member.CodePropertyIterable<? extends io.github.mmm.code.api.member.CodeProperty> getAll()io.github.mmm.code.api.member.CodePropertygetDeclared(String name) io.github.mmm.code.api.member.CodePropertiesDeprecated.Methods inherited from class BaseMembers
add, doWrite, getDeclaringType, getParent, renameMethods inherited from class BaseNodeItemContainer
addInternal, clear, doSetImmutable, ensureParent, getByName, getDeclared, getItemCopyType, getKey, getList, getMap, isKeepListView, isNamed, isSystemImmutable, removeMethods inherited from class BaseNodeItem
getContainerItem, getContainerItemDeclared, getContext, getLanguage, getSource, toPathStringMethods inherited from class BaseMutableItem
doCopyNode, doCopyNodeUnsafe, doMapList, doneInitialize, getDefaultCopyMapper, getDefaultEncoding, getReflectiveObject, initialize, initialize, isImmutable, isInitialized, isInitializing, isSystemImmutable, makeImmutable, makeImmutable, setImmutable, setImmutableIfNotSystemImmutable, verifyMutalbe, writeItemMethods inherited from class BaseItem
getOwningType, getSourceCode, getSpaces, toString, writeMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface io.github.mmm.code.api.item.CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface io.github.mmm.code.api.item.CodeItemWithDeclaringType
getDeclaringTypeMethods inherited from interface io.github.mmm.code.api.member.CodeMembers
add, getParentMethods inherited from interface io.github.mmm.code.api.object.CodeMutable
isImmutable, isMutableMethods inherited from interface io.github.mmm.code.api.item.CodeMutableItem
getReflectiveObject, setImmutableMethods inherited from interface io.github.mmm.code.api.node.CodeNodeContainer
getDeclared, isEmpty, iteratorMethods inherited from interface io.github.mmm.code.api.node.CodeNodeItemContainer
removeMethods inherited from interface io.github.mmm.code.api.node.CodeNodeItemContainerWithName
getDeclaredOrCreate, getOrCreate, getRequiredMethods inherited from interface io.github.mmm.code.api.copy.CodeNodeItemCopyable
getParentMethods inherited from interface io.github.mmm.code.api.CodeWithContext
getContext, getSourceMethods inherited from interface Iterable
forEach, spliterator
-
Constructor Details
-
BaseProperties
-
BaseProperties
The copy-constructor.- Parameters:
template- theBasePropertiesto copy.mapper- theCodeCopyMapper.
-
-
Method Details
-
doInitialize
protected void doInitialize()Description copied from class:BaseNodeItemCalled fromBaseMutableItem.initialize()on first invocation. May be overridden but never be called from anywhere else.- Overrides:
doInitializein classBaseNodeItem
-
getAll
- Specified by:
getAllin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>
-
get
- Specified by:
getin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
-
add
- Specified by:
addin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>- Specified by:
addin interfaceio.github.mmm.code.api.member.CodeProperties
-
getDeclared
- Specified by:
getDeclaredin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>
-
getSourceCodeObject
Deprecated.aBasePropertiesis a virtual object that can never have a source-code object.- Specified by:
getSourceCodeObjectin classBaseMembers<io.github.mmm.code.api.member.CodeProperty>- Returns:
- the optional internal
CodeItemrepresenting the source-code (to merge). Otherwisenull. This is an internal API. Do not use or rely on it from outside.
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.member.CodeMembers<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerHierarchical<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerHierarchicalWithName<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainerWithName<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>- Specified by:
copyin interfaceio.github.mmm.code.api.member.CodeProperties- Specified by:
copyin classBaseMembers<io.github.mmm.code.api.member.CodeProperty>
-
copy
- Specified by:
copyin interfaceio.github.mmm.code.api.item.CodeMutableItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItem- Specified by:
copyin interfaceio.github.mmm.code.api.node.CodeNodeItemContainer<io.github.mmm.code.api.member.CodeProperty>- Specified by:
copyin interfaceio.github.mmm.code.api.copy.CodeNodeItemCopyable<io.github.mmm.code.api.type.CodeType, io.github.mmm.code.api.member.CodeProperties>
-
BasePropertiesis a virtual object that can never have a source-code object.