Class BaseTextStatement
java.lang.Object
io.github.mmm.code.base.item.BaseItem
io.github.mmm.code.base.statement.BaseStatement
io.github.mmm.code.base.statement.BaseAtomicStatement
io.github.mmm.code.base.statement.BaseTextStatement
- All Implemented Interfaces:
io.github.mmm.code.api.item.CodeItem, io.github.mmm.code.api.item.CodeItemWithVariables, io.github.mmm.code.api.statement.CodeAtomicStatement, io.github.mmm.code.api.statement.CodeStatement
Base implementation of
CodeStatement that is unstructured and only contains the source-code as a
plain text.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface io.github.mmm.code.api.item.CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class BaseStatement
getVariableMethods inherited from class BaseItem
getOwningType, getSourceCode, getSpaces, toString, writeMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface io.github.mmm.code.api.item.CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface io.github.mmm.code.api.item.CodeItemWithVariables
getVariable
-
Constructor Details
-
BaseTextStatement
-
-
Method Details
-
getCode
- Returns:
- the line
-
doWrite
protected void doWrite(Appendable sink, String newline, String defaultIndent, String currentIndent, io.github.mmm.code.api.language.CodeLanguage language) throws IOException - Specified by:
doWritein classBaseItem- Parameters:
sink- theAppendablewhere toappendthe code from thisCodeItem.newline- the newlineString.defaultIndent- theStringused for indentation (e.g. a number of spaces to insert per indent level).currentIndent- the current indent (number of spaces). Initially the empty string (""). Before a recursion thedefaultIndentwill be appended.language- theCodeLanguageto use.- Throws:
IOException- if thrown byAppendable.- See Also:
-